@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # <sure - utility belt for automated testing in python>
-# Copyright (C) <2010-2013>  Gabriel Falcão <gabriel@nacaolivre.org>
+# Copyright (C) <2010-2021>  Gabriel Falcão <gabriel@nacaolivre.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,22 +22,24 @@ import inspect
 from copy import deepcopy
 from pprint import pformat
 from functools import wraps
-try:
-    from collections import Iterable
-except ImportError:
-    Iterable = (list, dict, tuple, set)
 
 try:
     import __builtin__ as builtins
 except ImportError:
     import builtins
 
+try:
+    from re import Pattern
+except ImportError:
+    Pattern = re._pattern_type
+
 from six import string_types, text_type
 
 from sure.core import DeepComparison
 from sure.core import _get_file_name
 from sure.core import _get_line_number
 from sure.core import itemize_length
+from sure.compat import Iterable
 
 
 def identify_callable_location(callable_object):
@@ -127,7 +129,7 @@ class AssertionHelper(object):
                 msg = exc
                 exc = type(e)
 
-            elif isinstance(exc, re._pattern_type):
+            elif isinstance(exc, Pattern):
                 msg = exc
                 exc = type(e)
 
@@ -147,7 +149,7 @@ class AssertionHelper(object):
                             type(e).__name__,
                             msg, err))
 
-                elif isinstance(msg, re._pattern_type) and not msg.search(err):
+                elif isinstance(msg, Pattern) and not msg.search(err):
                     raise AssertionError(
                         'When calling %r the exception message does not match. ' \
                         'Expected to match regex: %r\n against:\n %r' % (identify_callable_location(self._src), msg.pattern, err))
@@ -157,7 +159,7 @@ class AssertionHelper(object):
                     'When calling %r the exception message does not match. ' \
                     'Expected: %r\n got:\n %r' % (self._src, msg, err))
 
-            elif isinstance(msg, re._pattern_type) and not msg.search(err):
+            elif isinstance(msg, Pattern) and not msg.search(err):
                 raise AssertionError(
                     'When calling %r the exception message does not match. ' \
                     'Expected to match regex: %r\n against:\n %r' % (identify_callable_location(self._src), msg.pattern, err))
